package Simple::Filter::Macro;

# Set the VERSION.
$VERSION = "0.01";

# Load the Perl pragmas.
use strict;
use warnings;

# Outer filter starts here.
use Filter::Simple::Compile sub {
    # Remove the package terminator from the package content.
    $_ =~ s/1;\s//g;
    # Create the changed script content.
    $_ = sprintf(q(
        # Inner filter starts here.
        use Filter::Simple::Compile sub {
            # Concatenate content from package content to script content. 
            $_ = join("\n",
                '# Line ' . (__LINE__+1) . ' ' .__FILE__,
                "%s",
                '# Line %s %s',
                $_,
            );
        };
        # Inner filter ends here.
        1;
    ), $_, (caller(6))[2]+1, (caller(6))[1]);
};
# Outer filter ends here.
1;

=head1 NAME

Simple::Filter::Macro - Perl extension for creating macro modules that are expanding use declarations inline in Perl code.

=head1 SYNOPSIS

  use Simple::Filter::Macro;

=head1 DESCRIPTION

Expand C<use> pragma declarations to one C<use> pragma declaration. 

=head1 TO-DO

Improvement of the documentation.

=head1 MOTIVATION

I was looking for a module that would allow me to merge a number of C<use>
pragma declarations in the module and replace them with a single C<use>
pragma declaration. The module C<Filter::Macro> that I found contains the
right approaches for this, but is not executable under Perl v5.30 how I found
out. After analysing the source code, I decided to create a new module based
on the aforementioned approaches. The problem in the source code As I figured
out is the use of the Perl command C<quotemeta>. Since Perl v5.16 the use of
C<quotemeta> is obsolet as I suppose. The first attempts with basic changes in
the source code were not without errors. In the meantime, the Perl code works
as expected. The first two methods of this module are the result of my efforts.  

=head1 EXPORT

None

=head1 SEE ALSO

L<Filter::Simple::Compile|https://metacpan.org/pod/Filter::Simple::Compile/>

L<Filter::Macro|https://metacpan.org/pod/Filter::Macro/>

=head1 CREDITS

Special thanks go to Audrey Tang, who wrote the C<Filter::Macro> module, which
contains the crucial approaches to implementing the present module and its
methods. 

=head1 AUTHOR

Dr. Peter Netz, E<lt>deathlok@E<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2022 by Dr. Peter Netz

This library is free software; you can redistribute it and/or modify it
under the same terms of The MIT License. For more details, see the full
text of the license in the attached file LICENSE in the main module folder.
This program is distributed in the hope that it will be useful, but without
any warranty; without even the implied warranty of merchantability or fitness
for a particular purpose.

=cut
